@@ -26,7 +26,7 @@ setLocalTranslate('cl_builder3', sys.modules[__name__])
 __ = getLazyLocalTranslate(_)
 
 
-class DriveSpool(object):
+class DriveSpool():
     """
     Объект содержит спул устройств на которые можно устанавливать систему
     """
